@@ -14,9 +14,9 @@ class Uuid(ValueObject):
     def length():
         return 36
 
-    def __init__(self, value: str):
+    def __init__(self, value: str, execute_guard: bool = True):
         self.value = value
-        super(Uuid, self).__init__()
+        super(Uuid, self).__init__(execute_guard)
 
     def __hash__(self):
         return hash(str(self))
@@ -36,7 +36,7 @@ class Uuid(ValueObject):
         self._ensure_is_valid_uuid(self.value)
 
     def _ensure_is_valid_uuid(self, value):
-        if not validators.uuid(value):
+        if value is None or not validators.uuid(value):
             raise InvalidUuidError(value)
 
     @classmethod
