@@ -10,5 +10,5 @@ def mysql_is_running_locally() -> bool:
         is_running_locally = True
     except:  # noqa: E722
         is_running_locally = False
-    Persistence().remove("test")
+    Persistence().remove("test", skip_if_not_exist=True)
     return is_running_locally
