@@ -1,6 +1,8 @@
 import os
 from typing import List, Callable
 
+from sqlalchemy.orm import scoped_session
+
 from petisco.persistence.interface_database import IDatabase
 from petisco.persistence.persistence_models import PersistenceModels
 from petisco.persistence.sql.sql_session_scope_provider import (
@@ -11,7 +13,12 @@ from petisco.persistence.sql.sqlite.sqlite_connection import SqliteConnection
 
 class SqliteDatabase(IDatabase):
     def __init__(
-        self, name: str, connection: SqliteConnection, model_filename: str = None
+        self,
+        name: str,
+        connection: SqliteConnection,
+        model_filename: str = None,
+        print_sql_statements: bool = False,
+        use_scoped_session: bool = True,
     ):
         if not connection or not isinstance(connection, SqliteConnection):
             raise ConnectionError(
@@ -22,6 +29,8 @@ class SqliteDatabase(IDatabase):
         else:
             self.persistence_models = PersistenceModels(models={})
         self.connection = connection
+        self.print_sql_statements = print_sql_statements
+        self.use_scoped_session = use_scoped_session
         super().__init__(name, self.persistence_models.models)
         self._init()
 
@@ -40,6 +49,7 @@ class SqliteDatabase(IDatabase):
             self.connection.url,
             json_serializer=lambda obj: obj,
             json_deserializer=lambda obj: obj,
+            echo=self.print_sql_statements,
         )
 
         if not database_exists(engine.url):
@@ -83,7 +93,11 @@ class SqliteDatabase(IDatabase):
         return list(self.persistence_models.get_models_names().keys())
 
     def get_session(self):
-        return self.session_maker()
+        if self.use_scoped_session:
+            Session = scoped_session(self.session_maker)  # noqa
+        else:
+            Session = self.session_maker
+        return Session
 
     def get_session_scope(self) -> Callable:
         return sql_session_scope_provider(self.get_session())
